<?php

namespace Drupal\maintenance_preview\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\BareHtmlPageRendererInterface;
use Drupal\Core\Site\MaintenanceModeInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The maintenance page controller.
 */
class MaintenancePreviewController extends ControllerBase {

  /**
   * The bare HTML page renderer.
   *
   * @var \Drupal\Core\Render\BareHtmlPageRendererInterface
   */
  protected $bareHtmlPageRenderer;

  /**
   * The Maintenance Mode service.
   *
   * @var \Drupal\Core\Site\MaintenanceModeInterface
   */
  private MaintenanceModeInterface $maintenanceMode;

  /**
   * Constructs a new MaintenancePreviewController.
   *
   * @param \Drupal\Core\Render\BareHtmlPageRendererInterface $bare_html_page_renderer
   *   The bare HTML page renderer.
   */
  public function __construct(BareHtmlPageRendererInterface $bare_html_page_renderer, MaintenanceModeInterface $maintenance_mode) {
    $this->bareHtmlPageRenderer = $bare_html_page_renderer;
    $this->maintenanceMode = $maintenance_mode;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('bare_html_page_renderer'),
      $container->get('maintenance_mode')
    );
  }

  /**
   * Builds Drupal maintenance page.
   *
   * @return array
   *   The rendered HTML response.
   */
  public function page() {
    $content = [
      '#markup' => $this->maintenanceMode->getSiteMaintenanceMessage(),
    ];
    $title = '';

    return $this->bareHtmlPageRenderer->renderBarePage($content, $title, 'maintenance_page');
  }

}
